@@ -104,11 +104,30 @@ def hsize(size):
   :param size: Size in bytes.
 
   """
-  for suffix in ['B', 'kB', 'MB', 'GB', 'TB']:
+  for suffix in [' ', 'k', 'M', 'G', 'T']:
     if size < 1024.0:
-      return '%3.0f%s' % (size, suffix)
+      return '%4.0f%sB' % (size, suffix)
     size /= 1024.0
 
+def htime(time):
+  """Transform time from seconds to human readable format (min, hour, ...).
+
+  :param time: Time in seconds.
+
+  """
+  for (multiplier, suffix) in [
+    (60.0, 's'),
+    (60, 'm'),
+    (24, 'h'),
+    (7, 'd'),
+    (4, 'w'),
+    (12, 'M'),
+    (float('inf'), 'Y'),
+  ]:
+    if time < multiplier:
+      return '%4.1f%s' % (time, suffix)
+    time /= multiplier
+
 def catch(*error_classes):
   """Returns a decorator that catches errors and prints messages to stderr.
 
