@@ -43,3 +43,19 @@ class TestConfig(object):
       with open(tpath, 'w') as writer:
         writer.write('[foo_alias]\nauth=2\n')
       Config(tpath).get_alias('foo')
+
+
+class TestHuman(object):
+
+  def test_hsize(self):
+    eq_(hsize(0), '   0 B')
+    eq_(hsize(1023), '1023 B')
+    eq_(hsize(1024), '   1kB')
+
+  def test_htime(self):
+    eq_(htime(0), ' 0.0s')
+    eq_(htime(50), '50.0s')
+    eq_(htime(60), ' 1.0m')
+    eq_(htime(90), ' 1.5m')
+    eq_(htime(3600), ' 1.0h')
+    eq_(htime(3600 * 24 * 7 * 4 * 12 * 24), '24.0Y')
